<?php # $Id: serendipity_lang_cz.inc.php 2054 2007-12-06 09:26:35Z garvinhicking $
# Copyright (c) 2003-2005, Jannis Hermanns (on behalf the Serendipity Developer Team)
# All rights reserved.  See LICENSE file for licensing details
# Translation (c) 2004 Josef Klimosz <ok2wo@centrum.cz>
/* vim: set sts=4 ts=4 expandtab : */

@define('LANG_CHARSET', 'ISO-8859-2');
@define('SQL_CHARSET', 'latin2');
@define('DATE_LOCALES', 'cs_CZ.ISO-8859-2, cs_CZ.ISO8859-2, czech, cs');
@define('DATE_FORMAT_ENTRY', '%A, %e. %B %Y');
@define('DATE_FORMAT_SHORT', '%d/%m/%Y %H.%M');
@define('WYSIWYG_LANG', 'cs-iso');
@define('NUMBER_FORMAT_DECIMALS', '2');
@define('NUMBER_FORMAT_DECPOINT', ',');
@define('NUMBER_FORMAT_THOUSANDS', ' ');
@define('LANG_DIRECTION', 'ltr');

$i18n_filename_from = array (
'','','','','','','','','','','','','','','','','','','','',
'','','','','','','','','','','','','','','','','','','','',
' ',',','.','!',
);
$i18n_filename_to = array (
'a','c','d','e','e','i','l','l','n','o','r','r','s','s','t','u','u','y','z','z',
'A','C','D','E','E','I','L','L','N','O','R','R','S','S','T','U','U','Y','Z','Z',
'-', '', '', '',
);

@define('SERENDIPITY_ADMIN_SUITE', 'Administrtorsk sekce');
@define('HAVE_TO_BE_LOGGED_ON', 'Pro zobrazen tto strnky muste bt pihlen');
@define('WRONG_USERNAME_OR_PASSWORD', 'Zejm jste vloil patn jmno nebo heslo!');
@define('APPEARANCE', 'Vzhled');
@define('MANAGE_STYLES', 'Zmna stylu');
@define('CONFIGURE_PLUGINS', 'Konfigurace plugin');
@define('CONFIGURATION', 'Konfigurace');
@define('BACK_TO_BLOG', 'Zpt do weblogu');
@define('LOGIN', 'Pihlen');
@define('LOGOUT', 'Odhlen');
@define('LOGGEDOUT', 'Odhlen');
@define('CREATE', 'Vytvoit');
@define('SAVE', 'Uloit');
@define('NAME', 'Jmno');
@define('CREATE_NEW_CAT', 'Vytvoen nov kategorie');
@define('I_WANT_THUMB', 'Pout nhled.');
@define('I_WANT_BIG_IMAGE', 'Pout cel obrzek.');
@define('I_WANT_NO_LINK', ' Zobrazit jako obrzek');
@define('I_WANT_IT_TO_LINK', 'Zobrazit jako odkaz (URL):');
@define('BACK', 'Zpt');
@define('FORWARD', 'Dle');
@define('ANONYMOUS', 'Anonym');
@define('NEW_TRACKBACK_TO', 'Nov odezva na');
@define('NEW_COMMENT_TO', 'Nov koment k');
@define('RECENT', 'Nov...');
@define('OLDER', 'Star...');
@define('DONE', 'Hotovo');
@define('WELCOME_BACK', 'Vtejte zpt,');
@define('TITLE', 'Titulek');
@define('DESCRIPTION', 'Popis');
@define('PLACEMENT', 'Umstn');
@define('DELETE', 'Vymazat');
@define('SAVE', 'Uloit');
@define('UP', 'Nahoru');
@define('DOWN', 'Dol');
@define('ENTRIES', 'zznamy');
@define('NEW_ENTRY', 'Nov zznam');
@define('EDIT_ENTRIES', 'Editovat zznamy');
@define('CATEGORIES', 'Kategorie');
@define('WARNING_THIS_BLAHBLAH', "POZOR:\\nTato akce me trvat dle, pokud mte mnoho obrzk bez nhled.");
@define('CREATE_THUMBS', 'Vytvoit nhledy');
@define('MANAGE_IMAGES', 'Sprva obrzk');
@define('NAME', 'Jmno');
@define('EMAIL', 'E-mail');
@define('HOMEPAGE', 'Domc strnka');
@define('COMMENT', 'Koment');
@define('REMEMBER_INFO', 'Zapamatovat informace? ');
@define('SUBMIT_COMMENT', 'Odeslat koment');
@define('NO_ENTRIES_TO_PRINT', 'dn zznamy k zobrazen');
@define('COMMENTS', 'Komente');
@define('ADD_COMMENT', 'Pidat koment');
@define('NO_COMMENTS', 'dn komente');
@define('POSTED_BY', 'Vloil');
@define('ON', 'v');
@define('A_NEW_COMMENT_BLAHBLAH', 'Nov koment k weblogu "%s", k zznamu s nzvem "%s".');
@define('A_NEW_TRACKBACK_BLAHBLAH', 'Nov odezva na weblog/zznam s nzvem "%s".');
@define('NO_CATEGORY', 'dn kategorie');
@define('ENTRY_BODY', 'Text zznamu');
@define('EXTENDED_BODY', 'Rozen textov st');
@define('CATEGORY', 'Kategorie');
@define('EDIT', 'Editace');
@define('NO_ENTRIES_BLAHBLAH', 'Nenalezen dn zznam odpovdajc volb %s' . "\n");
@define('YOUR_SEARCH_RETURNED_BLAHBLAH', 'Vyhledvn %s odpovd %s vsledk:');
@define('IMAGE', 'Obrzek');
@define('ERROR_FILE_NOT_EXISTS', 'Chyba: Jmno souboru neexistuje!');
@define('ERROR_FILE_EXISTS', 'Chyba: Toto jmno souboru je u pouito, zvolte jin!');
@define('ERROR_SOMETHING', 'Chyba: Nco je patn.');
@define('ADDING_IMAGE', 'Pidn obrzku...');
@define('THUMB_CREATED_DONE', 'Nhled je vytvoen.<br>Hotovo.');
@define('ERROR_FILE_EXISTS_ALREADY', 'Chyba: Soubor u ve vaem potai existuje!');
@define('GO', 'Provst!');
@define('NEWSIZE', 'Nov rozmr: ');
@define('RESIZE_BLAHBLAH', '<b>Zmnit rozmr %s</b><p>');
@define('ORIGINAL_SIZE', 'Pvodn rozmr: <i>%sx%s</i> pixel');
@define('HERE_YOU_CAN_ENTER_BLAHBLAH', '<p>Zde mete zadat nov rozmr obrzku. Pokud chcete zachovat proporce, zadejte jen jednu hodnotu a stisknte klvesu TAB, nov rozmr bude dopotn automaticky:');
@define('QUICKJUMP_CALENDAR', 'Vyhledvac kalend');
@define('QUICKSEARCH', 'Rychl hledn');
@define('SEARCH_FOR_ENTRY', 'Hledn zznamu');
@define('ARCHIVES', 'Archivy');
@define('BROWSE_ARCHIVES', 'Prohlen msnch archiv');
@define('TOP_REFERRER', 'Top odkazovae');
@define('SHOWS_TOP_SITES', 'Nejastj pipojen k tomuto weblogu');
@define('TOP_EXITS', 'Top vstupy');
@define('SHOWS_TOP_EXIT', 'Nejastj vstupy z tohoto weblogu');
@define('SYNDICATION', 'Spoluprce');
@define('SHOWS_RSS_BLAHBLAH', 'Sdlen RSS linky');
@define('ADVERTISES_BLAHBLAH', 'Reklama na tvrce systmu vaeho weblogu');
@define('HTML_NUGGET', 'Vloen HTML kd');
@define('HOLDS_A_BLAHBLAH', 'Vloen HTML kdu do postrannho sloupce');
@define('TITLE_FOR_NUGGET', 'Nzev HTML kdu');
@define('THE_NUGGET', 'Vloen HTML');
@define('SYNDICATE_THIS_BLOG', 'Sdlen weblogu');
@define('YOU_CHOSE', 'Vybral jste %s');
@define('IMAGE_SIZE', 'Obrzek o rozmru');
@define('IMAGE_AS_A_LINK', 'Vloen obrzku');
@define('POWERED_BY', 'Vytvoeno pomoc');
@define('SUPERUSER', 'Superuivatel');
@define('TRACKBACKS', 'Odezvy');
@define('TRACKBACK', 'Odezva');
@define('NO_TRACKBACKS', 'dn odezvy');
@define('TOPICS_OF', 'Tma');
@define('VIEW_FULL', 'Zobrazit ve');
@define('VIEW_TOPICS', 'Zobrazit tma');
@define('AT', 'v');
@define('SET_AS_TEMPLATE', 'Nastavit jako vzor');
@define('IN', 've');
@define('EXCERPT', 'Vpis');
@define('TRACKED', 'Sledovn');
@define('LINK_TO_ENTRY', 'Odkaz na zznam');
@define('LINK_TO_REMOTE_ENTRY', 'Odkaz na extern zznam');
@define('IP_ADDRESS', 'IP adresa');
@define('USER', 'Uivatel');
@define('THUMBNAIL_USING_OWN', '%s je pouit jako vlastn nhled, protoe je pli mal.');
@define('THUMBNAIL_FAILED_COPY', '%s nelze pout jako vlastn nhled, nebo jej nelze zkoprovat!');
@define('AUTHOR', 'Autor');
@define('LAST_UPDATED', 'Naposled zmnno');
@define('TRACKBACK_SPECIFIC', 'Odezva ze specifickho URI na tento zznam');
@define('DIRECT_LINK', 'Pm odkaz na tento zznam');
@define('COMMENT_ADDED', 'V koment byl spn pidn.');
@define('COMMENT_ADDED_CLICK', 'Kliknte %ssem%s pro nvrat ke komentm nebo %ssem%s pro zaven okna.');
@define('COMMENT_NOT_ADDED_CLICK', 'Kliknte %ssem%s pro nvrat ke komentm nebo %ssem%s pro zaven okna.');
@define('COMMENTS_DISABLE', 'Neumonit pidvn koment');
@define('COMMENTS_ENABLE', 'Umonit pidvn koment');
@define('COMMENTS_CLOSED', 'Autor neumonil pidvat komente');
@define('EMPTY_COMMENT', 'V koment nic neobsahuje, %svrate se%s a zkuste to znovu');
@define('ENTRIES_FOR', 'Zznamy: %s');
@define('DOCUMENT_NOT_FOUND', 'Dokument %s nebyl nalezen.');
@define('USERNAME', 'Jmno (pezdvka)');
@define('PASSWORD', 'Heslo');
@define('AUTOMATIC_LOGIN', 'Uloit informace');
@define('SERENDIPITY_INSTALLATION', 'Instalace Serendipity');
@define('LEFT', 'vlevo');
@define('RIGHT', 'vpravo');
@define('HIDDEN', 'skryt');
@define('REMOVE_TICKED_PLUGINS', 'Odstranit oznaen pluginy');
@define('SAVE_CHANGES_TO_LAYOUT', 'Uloit zmny layoutu');
@define('COMMENTS_FROM', 'Komente od');
@define('ERROR', 'Chyba');
@define('ENTRY_SAVED', 'Zznam uloen');
@define('DELETE_SURE', 'Urit chcete vymazat #%s natrvalo?');
@define('NOT_REALLY', 'Nechci...');
@define('DUMP_IT', 'Vymazat!');
@define('RIP_ENTRY', 'Zruen zznam #%s');
@define('CATEGORY_DELETED_ARTICLES_MOVED', 'Kategorie #%s byla zruena. Star zznamy byly pemstny do #%s');
@define('CATEGORY_DELETED', 'Kategorie #%s byla zruena.');
@define('INVALID_CATEGORY', 'dn kategorie nebyla urena k vymazn');
@define('CATEGORY_SAVED', 'Kategorie uloena');
@define('SELECT_TEMPLATE', 'Vyberte vzor pro v web');
@define('ENTRIES_NOT_SUCCESSFULLY_INSERTED', 'Zznamy nebyly vloeny spn!');
@define('YES', 'Ano');
@define('NO', 'Ne');
@define('USE_DEFAULT', 'Default');
@define('CHECK_N_SAVE', 'Provit a uloit');
@define('DIRECTORY_WRITE_ERROR', 'Nelze zapisovat do adrese %s - provte oprvnn.');
@define('DIRECTORY_CREATE_ERROR', 'Adres %s neexistuje a nemohl bt vytvoen. Vytvote adres manuln.');
@define('DIRECTORY_RUN_CMD', '&nbsp;-&gt; spustit <i>%s %s</i>');
@define('CANT_EXECUTE_BINARY', 'Nelze spustit binrn soubor %s.');
@define('FILE_WRITE_ERROR', 'Nelze zapisovat do souboru %s.');
@define('FILE_CREATE_YOURSELF', 'Vytvote soubor pmo nebo provte oprvnn');
@define('COPY_CODE_BELOW', '<br />* Zkoprujte kd uveden ne a umstte jej do %s ve vaem %s adresi:<b><pre>%s</pre></b>' . "\n");
@define('WWW_USER', 'Zmte www na uivatele, kter je uren v Apache (na p. nobody).');
@define('BROWSER_RELOAD', 'Po dokonen stisknte tlatko obnoven strnky ve vaem prohlei.');
@define('DIAGNOSTIC_ERROR', 'Diagnostika detekovala njak chyby ve vkldanch informacch:');
@define('SERENDIPITY_NOT_INSTALLED', 'Serendipity jet nen nainstalovn. <a href="%s">Instalujte</a> jej nyn.');
@define('INCLUDE_ERROR', 'chyba serendipity: nelze vloit %s - ukoneno.');
@define('DATABASE_ERROR', 'chyba serendipity: nelze se spojit s databz - ukoneno.');
@define('CREATE_DATABASE', 'Vytvoen zkladn databze...');
@define('ATTEMPT_WRITE_FILE', 'Pokus uloit soubor %s...');
@define('WRITTEN_N_SAVED', 'Konfigurace byla zapsna a uloena');
@define('IMAGE_ALIGNMENT', 'prava obrzku');
@define('ENTER_NEW_NAME', 'Nov nzev: ');
@define('RESIZING', 'Zmna rozmr');
@define('RESIZE_DONE', 'Hotovo (upraven rozmr %s obrzk).');
@define('SYNCING', 'Synchronizace databze s adresem obrzk');
@define('SYNC_DONE', 'Hotovo (synchronizovno %s obrzk).');
@define('DELETE_IMAGE_FAIL' , 'Nelze vymazat obrzek <b>%s</b>');
@define('DELETE_THUMBNAIL', 'Vymazn nhled obrzku s nzvem <b>%s</b>');
@define('FILE_NOT_FOUND', 'Nelze nalzt soubor s nzvem <b>%s</b>, mon je opravdu vymazn?');
@define('ABORT_NOW', 'Zruit');
@define('REMOTE_FILE_NOT_FOUND', 'Soubor nebyl na vzdlenm serveru nalezen, jste si jist e URL: <b>%s</b> je sprvn?');
@define('FILE_FETCHED', '%s nalezen');
@define('FILE_UPLOADED', 'Soubor %s je spn nahrn.');
@define('WORD_OR', 'nebo');
@define('SCALING_IMAGE', 'Zmna %s na %s x %s px');
@define('KEEP_PROPORTIONS', 'Zachovat proporce');
@define('REALLY_SCALE_IMAGE', 'Opravdu zmnit rozmr? Nelze vrtit!');
@define('TOGGLE_ALL', 'Otevt ve');
@define('TOGGLE_OPTION', 'Otevt volbu');
@define('SUBSCRIBE_TO_THIS_ENTRY', 'Pihlsit se ke sledovn koment k zznamu');
@define('UNSUBSCRIBE_OK', "%s je odhlen ze sledovn koment");
@define('NEW_COMMENT_TO_SUBSCRIBED_ENTRY', 'Nov koment k pihlenmu zznamu "%s"');
@define('SUBSCRIPTION_MAIL', "Pozor %s,\n\nA prv byl pidn nov koment k zznamu, kter sledujete na \"%s\", s nzvem \"%s\"\nJmno odeslatele: %s\n\nZznam najdete zde: %s\n\nMete se odhlsit zde: %s\n");
@define('SUBSCRIPTION_TRACKBACK_MAIL', "Pozor %s,\n\nA prv byla pidna nov odezva k zznamu, kter sledujete na \"%s\", s nzvem \"%s\"\nJmno odeslatele: %s\n\nZznam najdete zde: %s\n\nMete se odhlsit zde: %s\n");
@define('SIGNATURE', "\n-- \n%s je vytvoen pomoc Serendipity.\n Tento perfektn blogovac systm mete zdarma pouvat tak.\nNavtivte <http://s9y.org>, kde se dozvte ve potebn.");
@define('SYNDICATION_PLUGIN_091', 'Kanl RSS 0.91');
@define('SYNDICATION_PLUGIN_20', 'Kanl RSS 2.0');
@define('SYNDICATION_PLUGIN_10', 'Kanl RSS 1.0');
@define('SYNDICATION_PLUGIN_20c', 'Komente RSS 2.0');
@define('SYNDICATION_PLUGIN_ATOM03', 'Kanl ATOM 0.3');
@define('SYNDICATION_PLUGIN_GENERIC_FEED', 'Kanl %s');
@define('SYNDICATION_PLUGIN_MANAGINGEDITOR', 'Pole "hlavn redaktor"');
@define('SYNDICATION_PLUGIN_WEBMASTER',  'Pole "webmaster"');
@define('SYNDICATION_PLUGIN_BANNERURL', 'Obrzek kanlu RSS');
@define('SYNDICATION_PLUGIN_BANNERWIDTH', 'ka');
@define('SYNDICATION_PLUGIN_BANNERHEIGHT', 'Vka');
@define('SYNDICATION_PLUGIN_WEBMASTER_DESC',  'E-mailov adresa webmastera, je-li k dispozici. (przdn: skryt) [RSS 2.0]');
@define('SYNDICATION_PLUGIN_MANAGINGEDITOR_DESC', 'E-mailov adresa hlavnho redaktora, je-li k dispozici. (przdn: skryt) [RSS 2.0]');
@define('SYNDICATION_PLUGIN_BANNERURL_DESC', 'URL obrzku ve formtu GIF/JPEG/PNG, je-li k dispozici. (przdn: logo serendipity)');
@define('SYNDICATION_PLUGIN_BANNERWIDTH_DESC', 'v pixelech, max. 144');
@define('SYNDICATION_PLUGIN_BANNERHEIGHT_DESC', 'v pixelech, max. 400');
@define('SYNDICATION_PLUGIN_TTL', 'Pole "ttl" (ivotnost)');
@define('SYNDICATION_PLUGIN_TTL_DESC', 'as v minutch, po kterm by v weblog neml bt nadle keovn v cizch serverech/aplikacch (przdn: skryt) [RSS 2.0]');
@define('SYNDICATION_PLUGIN_PUBDATE', 'Pole "pubDate"');
@define('SYNDICATION_PLUGIN_PUBDATE_DESC', 'Pole "pubDate" je pro kanl RSS ukryto, chcete ukzat datum poslednho zznamu?');
@define('CONTENT', 'Obsah');
@define('TYPE', 'Typ');
@define('DRAFT', 'Koncept');
@define('PUBLISH', 'Publikovat');
@define('PREVIEW', 'Ukzat');
@define('DATE', 'Datum');
@define('DATE_FORMAT_2', 'Y-m-d H:i'); // Needs to be ISO 8601 compliant for date conversion!
@define('DATE_INVALID', 'Upozornn: Datum je specifikovno patn. Pouijte formt YYYY-MM-DD HH:MM.');
@define('CATEGORY_PLUGIN_DESC', 'Seznam kategori.');
@define('ALL_AUTHORS', 'Vichni autoi');
@define('CATEGORIES_TO_FETCH', 'Vyhledat kategorie');
@define('CATEGORIES_TO_FETCH_DESC', 'Vyhledat kategorie podle autor?');
@define('PAGE_BROWSE_ENTRIES', 'Strnka %s z %s, celkem %s zznam');
@define('PREVIOUS_PAGE', 'pedchoz strnka');
@define('NEXT_PAGE', 'dal strnka');
@define('ALL_CATEGORIES', 'Vechny kategorie');
@define('DO_MARKUP', 'Umonit pevod znaek');
@define('GENERAL_PLUGIN_DATEFORMAT', 'Formtovn data');
@define('GENERAL_PLUGIN_DATEFORMAT_BLAHBLAH', 'Formt aktulnho data zznamu, pouv PHP promnnou strftime(). (Pednastaveno: "%s")');
@define('ERROR_TEMPLATE_FILE', 'Nelze otevt vzorov soubor, updatujte Serendipity!');
@define('ADVANCED_OPTIONS', 'Rozen volby');
@define('EDIT_ENTRY', 'Editovat zznam');
@define('HTACCESS_ERROR', 'Provte instalaci vaeho webserveru, Serendipity potebuje uloit soubor ".htaccess". To nebylo mon kvli chyb oprvnn. Nastavte oprvnn jako: <br />&nbsp;&nbsp;%s<br />a znovu ulote tuto strnku.');
@define('SIDEBAR_PLUGINS', 'Pluginy pro postrann sloupce');
@define('EVENT_PLUGINS', 'Pluginy udlost');
@define('SORT_ORDER', 'Poad');
@define('SORT_ORDER_NAME', 'Nzev souboru');
@define('SORT_ORDER_EXTENSION', 'Rozen');
@define('SORT_ORDER_SIZE', 'Velikost');
@define('SORT_ORDER_WIDTH', 'ka obrzku');
@define('SORT_ORDER_HEIGHT', 'Vka obrzku');
@define('SORT_ORDER_DATE', 'Datum nahrn');
@define('SORT_ORDER_ASC', 'Vzestupn');
@define('SORT_ORDER_DESC', 'Sestupn');
@define('THUMBNAIL_SHORT', 'Nhl.');
@define('ORIGINAL_SHORT', 'Orig.');
@define('APPLY_MARKUP_TO', 'Zapnout znakovn %s');
@define('CALENDAR_BEGINNING_OF_WEEK', 'Zatek tdne');
@define('SERENDIPITY_NEEDS_UPGRADE', 'Serendipity detekoval, e vae konfigurace je uloena ve verzi %s, ale serendipity je instalovn jako verze %s, je poteba upgrade! <a href="%s">Kliknte zde</a>');
@define('SERENDIPITY_UPGRADER_WELCOME', 'Vt vs manaer upgrade Serendipity.');
@define('SERENDIPITY_UPGRADER_PURPOSE', 'Pomohu vm s upgrade va instalace Serendipity %s.');
@define('SERENDIPITY_UPGRADER_WHY', 'Tato zprva je zobrazena proto, e vae instalace je Serendipity %s, ale jet nebyla updatovna databze pro tuto verzi');
@define('SERENDIPITY_UPGRADER_DATABASE_UPDATES', 'Update databze (%s)');
@define('SERENDIPITY_UPGRADER_FOUND_SQL_FILES', 'Zde jsou .sql soubory, kter muste spustit ped pokraovnm prce se Serendipity');
@define('SERENDIPITY_UPGRADER_VERSION_SPECIFIC',  'lohy specifick pro tuto verzi');
@define('SERENDIPITY_UPGRADER_NO_VERSION_SPECIFIC', 'dn specifick lohy');
@define('SERENDIPITY_UPGRADER_PROCEED_QUESTION', 'Mohu pokraovat v tchto lohch?');
@define('SERENDIPITY_UPGRADER_PROCEED_ABORT', 'Ne, spustm je manuln');
@define('SERENDIPITY_UPGRADER_PROCEED_DOIT', 'Ano, pokraujte');
@define('SERENDIPITY_UPGRADER_NO_UPGRADES', 'Nen teba dn upgrade');
@define('SERENDIPITY_UPGRADER_CONSIDER_DONE', 'Serendipity je upgradovn');
@define('SERENDIPITY_UPGRADER_YOU_HAVE_IGNORED', 'Vynechal jste stupe upgrade Serendipity, ujistte se, e databze je sprvn nainstalovna a plnovan funkce jsou sputny');
@define('SERENDIPITY_UPGRADER_NOW_UPGRADED', 'Vae instalace Serendipity je upgradovna na %s');
@define('SERENDIPITY_UPGRADER_RETURN_HERE', 'Kliknutm %ssem%s se vrtte do vaeho weblogu');
@define('MANAGE_USERS', 'Sprva uivatel');
@define('CREATE_NEW_USER', 'Vytvoit novho uivatele');
@define('CREATE_NOT_AUTHORIZED', 'Nemete editovat uivatele se stejnou rovn jako je vae');
@define('CREATE_NOT_AUTHORIZED_USERLEVEL', 'Nemete vytvoit uivatele s vy rovn ne je vae');
@define('CREATED_USER', 'Nov uivatel %s byl vytvoen');
@define('MODIFIED_USER', 'Nastaven uivatele %s byla zmnna');
@define('USER_LEVEL', 'rove');
@define('DELETE_USER', 'Chcete vymazat uivatele #%d %s. Myslte to vn? Tato akce znemon prohlet jm vytvoen zznamy na hlavn strnce.');
@define('DELETED_USER', 'Uivatel #%d %s je vymazn.');
@define('LIMIT_TO_NUMBER', 'Kolik zznam by mlo bt zobrazeno?');
@define('ENTRIES_PER_PAGE', 'zznam na strnku');
@define('DIRECTORIES_AVAILABLE', 'Po kliknut na nkter adres v seznamu mete vytvoit dal podadres.');
@define('ALL_DIRECTORIES', 'vechny adrese');
@define('MANAGE_DIRECTORIES', 'Prce s adresi');
@define('DIRECTORY_CREATED', 'Adres <strong>%s</strong> byl vytvoen.');
@define('PARENT_DIRECTORY', 'Zkladn adres');
@define('CONFIRM_DELETE_DIRECTORY', 'Jste si jist, e chcete odstranit vechen obsah adrese %s?');
@define('ERROR_NO_DIRECTORY', 'Chyba: Adres %s neexistuje');
@define('CHECKING_DIRECTORY', 'Kontrola soubor v adresi %s');
@define('DELETING_FILE', 'Vymazn souboru %s...');
@define('ERROR_DIRECTORY_NOT_EMPTY', 'Nelze odstranit neprzdn adres. Zkuste zvolit "vynucen mazn", pokud potebujete vymazat tyto soubory, a odelete poadavek znovu. Existujc soubory jsou:');
@define('DIRECTORY_DELETE_FAILED', 'Vymazn adrese %s se nepodailo. Zkontrolujte oprvnn nebo tte zprvu ve.');
@define('DIRECTORY_DELETE_SUCCESS', 'Adres %s byl spn vymazn.');
@define('SKIPPING_FILE_EXTENSION', 'Vynechn soubor: Chybjc ppona %s.');
@define('SKIPPING_FILE_UNREADABLE', 'Vynechn soubor: %s nelze nast.');
@define('FOUND_FILE', 'Zaloit nov/zmnit soubor: %s.');
@define('PERMISSIONS', 'Oprvnn');

/* DATABASE SETTINGS */
@define('INSTALL_CAT_DB', 'Databze');
@define('INSTALL_CAT_DB_DESC', 'Sem vlote vech informace o databzi. Serendipity je potebuje k funkci.');
@define('INSTALL_DBTYPE', 'Typ');
@define('INSTALL_DBTYPE_DESC', 'Typ databze');
@define('INSTALL_DBHOST', 'Hostitel');
@define('INSTALL_DBHOST_DESC', 'Nzev hostitelskho serveru');
@define('INSTALL_DBUSER', 'Uivatel');
@define('INSTALL_DBUSER_DESC', 'Uivatelsk jmno');
@define('INSTALL_DBPASS', 'Heslo');
@define('INSTALL_DBPASS_DESC', 'Uivatelsk heslo');
@define('INSTALL_DBNAME', 'Nzev');
@define('INSTALL_DBNAME_DESC', 'Nzev databze');
@define('INSTALL_DBPREFIX', 'Prefix');
@define('INSTALL_DBPREFIX_DESC', 'Prefix pro zznamy v databzi, nap. serendipity_');

/* PATHS */
@define('INSTALL_CAT_PATHS', 'Cesty');
@define('INSTALL_CAT_PATHS_DESC', 'Cesty k rznm adresm a souborm. Nezapomete na ukonovac lomtko pro adrese!');
@define('INSTALL_FULLPATH', 'pln cesta');
@define('INSTALL_FULLPATH_DESC', 'pln absolutn cesta k va instalaci Serendipity.');
@define('INSTALL_UPLOADPATH', 'Cesta pro uploady');
@define('INSTALL_UPLOADPATH_DESC', 'Sem budou smrovny uploady, relativn k \'pln cest\' - typicky \'uploads/\'');
@define('INSTALL_RELPATH', 'Relativn cesta');
@define('INSTALL_RELPATH_DESC', 'Cesta k Serendipity pro v prohle, typicky \'/serendipity/\'');
@define('INSTALL_RELTEMPLPATH', 'Relativn cesta k template');
@define('INSTALL_RELTEMPLPATH_DESC', 'Cesta k adresi, obsahujcmu vzory (templates) - relativn k \'relativn cest\'');
@define('INSTALL_RELUPLOADPATH', 'Relativn cesta k uploadm');
@define('INSTALL_RELUPLOADPATH_DESC', 'Cesta k uploadm pro prohlee - relativn k \'relativn cest\'');
@define('INSTALL_URL', 'URL weblogu');
@define('INSTALL_URL_DESC', 'Zkladn URL va instalace Serendipity');
@define('INSTALL_INDEXFILE', 'Indexov soubor');
@define('INSTALL_INDEXFILE_DESC', 'Nzev souboru pouitho jako index');

/* Generel settings */
@define('INSTALL_CAT_SETTINGS', 'Zkladn nastaven');
@define('INSTALL_CAT_SETTINGS_DESC', 'prava sprvy Serendipity');
@define('INSTALL_USERNAME', 'Jmno admina');
@define('INSTALL_USERNAME_DESC', 'Jmno pro pihlen admina');
@define('INSTALL_PASSWORD', 'Heslo admina');
@define('INSTALL_PASSWORD_DESC', 'Heslo pro pihlen admina');
@define('INSTALL_EMAIL', 'E-mail admina');
@define('INSTALL_EMAIL_DESC', 'E-mail pro pihlen admina');
@define('INSTALL_SENDMAIL', 'Poslat e-maily adminovi?');
@define('INSTALL_SENDMAIL_DESC', 'Chcete dostvat e-mailem zprvy o komentch k vaim zznamm?');
@define('INSTALL_SUBSCRIBE', 'Umonit odbr koment?');
@define('INSTALL_SUBSCRIBE_DESC', 'Umonit uivatelm pihlen k odbru koment k zznamm');
@define('INSTALL_BLOGNAME', 'Nzev');
@define('INSTALL_BLOGNAME_DESC', 'Nzev vaeho weblogu');
@define('INSTALL_BLOGDESC', 'Popis');
@define('INSTALL_BLOGDESC_DESC', 'Popis weblogu');
@define('INSTALL_LANG', 'Jazyk');
@define('INSTALL_LANG_DESC', 'Vyberte jazyk vaeho weblogu');

/* Appearance and options */
@define('INSTALL_CAT_DISPLAY', 'Vzhled a volby');
@define('INSTALL_CAT_DISPLAY_DESC', 'prava vzhledu a chovn Serendipity');
@define('INSTALL_WYSIWYG', 'Pouvat WYSIWYG editor?');
@define('INSTALL_WYSIWYG_DESC', 'Chcete pouvat WYSIWYG editor? (Pracuje v IE5+, sten v Mozille 1.3+)');
@define('INSTALL_XHTML11', 'Vnutit kompatibilitu s XHTML 1.1?');
@define('INSTALL_XHTML11_DESC', 'Chcete plnou kompatibilitu s XHTML 1.1? (me zpsobit problmy ve starch prohlech)');
@define('INSTALL_POPUP', 'Umonit pouit vyskakovacch oken');
@define('INSTALL_POPUP_DESC', 'Chcete ve weblogu pouvat vyskakovac okna pro komente, odezvy a pod.?');
@define('INSTALL_EMBED', 'Je Serendipity vloen?');
@define('INSTALL_EMBED_DESC', 'Pokud chcete umstit weblog do vaich strnek, zvolte ano pro odstrann vech zhlav, bude zobrazovn jen obsah. Mete pout voliteln soubor indexFile pro obalen obsahu vlastnmi zhlavmi a sloupci. Vce informac najdete v souboru README!');
@define('INSTALL_BLOCKREF', 'Blokovan odbratel');
@define('INSTALL_BLOCKREF_DESC', 'Chcete zamezit pstup z uritch adres? Seznam adres oddlujte \';\' a pozor, adresy jsou blokovny vetn subadres!');
@define('INSTALL_REWRITE', 'Pepisovn URL');
@define('INSTALL_REWRITE_DESC', 'Uren pravidel pro tvorbu URL. Zapnut mdu pepisovn zajist sprvn URL vaeho weblogu a lep indexaci pro vyhledvae, jako je Google. V webserver mus podporovat mod_rewrite nebo "AllowOverride All" v adresi pro Serendipity. Defaultn nastaven je automaticky detekovno.');

/* Imageconversion Settings */
@define('INSTALL_CAT_IMAGECONV', 'pravy obrzk');
@define('INSTALL_CAT_IMAGECONV_DESC', 'Vloen zkladnch informac o zpsobu zpracovn obrzk');
@define('INSTALL_IMAGEMAGICK', 'Pouvat Imagemagick?');
@define('INSTALL_IMAGEMAGICK_DESC', 'Mte instalovn Imagemagick?');
@define('INSTALL_IMAGEMAGICKPATH', 'Cesta ke konverznmu souboru');
@define('INSTALL_IMAGEMAGICKPATH_DESC', 'pln cesta a nzev konverznho souboru Imagemagick');
@define('INSTALL_THUMBSUFFIX', 'Sufix nhled');
@define('INSTALL_THUMBSUFFIX_DESC', 'Nhledy budou pojmenovny original.sufix.ext');
@define('INSTALL_THUMBWIDTH', 'Rozmry nhled');
@define('INSTALL_THUMBWIDTH_DESC', 'Pevn ka automaticky generovanch nhled');

/* Personal details */
@define('USERCONF_CAT_PERSONAL', 'Osobn nastaven');
@define('USERCONF_CAT_PERSONAL_DESC', 'Nastaven vaeho tu');
@define('USERCONF_USERNAME', 'Jmno');
@define('USERCONF_USERNAME_DESC', 'Vae uivatelsk jmno (pezdvka)');
@define('USERCONF_PASSWORD', 'Heslo');
@define('USERCONF_PASSWORD_DESC', 'Vae heslo');
@define('USERCONF_EMAIL', 'E-mailov adresa');
@define('USERCONF_EMAIL_DESC', 'V e-mail');
@define('USERCONF_SENDCOMMENTS', 'Poslat zprvy o komentch?');
@define('USERCONF_SENDCOMMENTS_DESC', 'Chcete dostvat zprvy o komentch e-mailem?');
@define('USERCONF_SENDTRACKBACKS', 'Poslat zprvy o odezvch?');
@define('USERCONF_SENDTRACKBACKS_DESC', 'Chcete dostvat zprvy o odezvch na zznamy e-mailem?');
@define('USERCONF_ALLOWPUBLISH', 'Prvo publikovat zznamy?');
@define('USERCONF_ALLOWPUBLISH_DESC', 'Umonit uivateli publikovat zznamy');

@define('ALREADY_SUBCATEGORY', '%s je opravdu subkategorie pod %s.');
@define('PARENT_CATEGORY', 'Nadazen kategorie');
@define('IN_REPLY_TO', 'Odpov na');
@define('TOP_LEVEL', 'Nejvy rove');
@define('XML_IMAGE_TO_DISPLAY', 'Znak XML');
@define('XML_IMAGE_TO_DISPLAY_DESC','Odkazy na XML kanly budou zobrazeny s tmto znakem. Nechejte przdn pro pvodn nastaven, nebo zadejte \'none\' pro vypnut.');
@define('SUCCESS', 'spch');

@define('POWERED_BY_SHOW_TEXT', 'Zobrazit "Serendipity" jako text');
@define('POWERED_BY_SHOW_TEXT_DESC', 'Vytvoeno v "Serendipity" se zobraz jako text');
@define('POWERED_BY_SHOW_IMAGE', 'Zobrazit "Serendipity" s logem');
@define('POWERED_BY_SHOW_IMAGE_DESC', 'Zobraz se logo Serendipity');
@define('INSTALL_TOP_AS_LINKS', 'Zobrazit Top vstupy/odbratele jako linky?');
@define('INSTALL_TOP_AS_LINKS_DESC', '"Ne": Vstupy a adresy odbratel budou zobrazeny jako ist text pro zamezen spamu, "Ano": nebo jako hyperlinky. "Default": Pout globln nastaven (doporueno).');
@define('SETTINGS_SAVED_AT', 'Nov nastaven bylo uloeno v %s');
@define('PLUGIN_ITEM_DISPLAY', 'Kde by mla bt tato poloka zobrazena?');
@define('PLUGIN_ITEM_DISPLAY_EXTENDED', 'V rozen sti');
@define('PLUGIN_ITEM_DISPLAY_OVERVIEW', 'V pehledu');
@define('PLUGIN_ITEM_DISPLAY_BOTH', 'V obou stech');

@define('RSS_IMPORT_CATEGORY', 'Pout tuto kategorii pro neuren zznamy');
@define('ERROR_UNKNOWN_NOUPLOAD', 'Neznm chyba, soubor nebyl nahrn. Je mon, e dlka souboru pekrauje maximum, povolen serverem. Spojte se s vam ISP nebo editujte soubor php.ini a povolte vt velikost.');
@define('COMMENTS_WILL_BE_MODERATED', 'Odeslan komente budou ped uveejnnm moderovny.');
@define('YOU_HAVE_THESE_OPTIONS', 'Mte k dispozici tyto volby:');
@define('THIS_COMMENT_NEEDS_REVIEW', 'Pozor: Tento koment mus bt ped uveejnnm odsouhlasen');
@define('DELETE_COMMENT', 'Vymazat koment');
@define('APPROVE_COMMENT', 'Odsouhlasit koment');
@define('REQUIRES_REVIEW', 'Vydat pezkoumn');
@define('COMMENT_APPROVED', 'Koment #%s byl odsouhlasen');
@define('COMMENT_DELETED', 'Koment #%s byl vymazn');
@define('VIEW', 'Ukzat');
@define('COMMENT_ALREADY_APPROVED', 'Koment #%s se jev jako skuten odsouhlasen');
@define('COMMENT_EDITED', 'Vybran koment byl editovn');
@define('HIDE', 'Skrt');
@define('VIEW_EXTENDED_ENTRY', 'Pokraovat ve ten "%s"');
@define('TRACKBACK_SPECIFIC_ON_CLICK', 'Tento odkaz nen mnn jako klikateln. Obsahuje zptn URI zznamu. Tento URI mete pout k odesln ping a sledovn odezvy na tento zznam. Odkaz zkoprujete kliknutm pravou my a volbou "Koprovat odkaz" v Internet Exploreru nebo "Zkoprovat umstn odkazu" v Mozille.');
@define('THIS_TRACKBACK_NEEDS_REVIEW', 'Pozor: Tato odezva mus bt ped uveejnnm odsouhlasena');
@define('DELETE_TRACKBACK', 'Vymazat odezvu');
@define('APPROVE_TRACKBACK', 'Odsouhlasit odezvu');
@define('TRACKBACK_APPROVED', 'Odezva #%s byla odsouhlasena');
@define('TRACKBACK_DELETED', 'Odezva #%s byla vymazna');
@define('COMMENTS_MODERATE', 'Komente a odezvy k tomuto zznamu budou moderovny');
@define('PLUGIN_SUPERUSER_HTTPS', 'Pout https pro pihlen');
@define('PLUGIN_SUPERUSER_HTTPS_DESC', 'Umouje pout spojen https pro pihlen. V server to mus podporovat!');
@define('INSTALL_SHOW_EXTERNAL_LINKS', 'Udlat extern odkazy klikateln?');
@define('INSTALL_SHOW_EXTERNAL_LINKS_DESC', '"Ne": Neoznaen extern odkazy (Top vstupy, Top odbratel, Uivatelsk komente) nebudou ukzny/budou ukzny jako bn text vude, kde je to mon, pro omezen spamu (doporueno). "Ano": Neoznaen extern odkazy budou ukzny jako hyperlinky. Toto me bt pepsno v konfiguraci plugin!');
@define('PAGE_BROWSE_COMMENTS', 'Strnka %s ze %s, celkem %s koment');
@define('FILTERS', 'Filtry');
@define('FIND_ENTRIES', 'Hledat zznamy');
@define('FIND_COMMENTS', 'Hledat komente');
@define('FIND_MEDIA', 'Hledat mdia');
@define('FILTER_DIRECTORY', 'Adres');
@define('SORT_BY', 'Seadit podle');
@define('TRACKBACK_COULD_NOT_CONNECT', 'Odezva nebyla odeslna: nepodailo se spojen s %s na portu %d');
@define('MEDIA', 'Mdia (obrzky)');
@define('MEDIA_LIBRARY', 'Knihovna mdi');
@define('ADD_MEDIA', 'Pidat');
@define('ENTER_MEDIA_URL', 'Vlote URL pidvanho souboru:');
@define('ENTER_MEDIA_UPLOAD', 'Vyberte soubor pro nahrn:');
@define('SAVE_FILE_AS', 'Uloit soubor jako:');
@define('STORE_IN_DIRECTORY', 'Uloit do nsledujho adrese: ');
@define('MEDIA_RENAME', 'Pejmenovat soubor');
@define('IMAGE_RESIZE', 'Zmnit rozmr obrzku');
@define('MEDIA_DELETE', 'Vymazat soubor');
@define('FILES_PER_PAGE', 'Soubor na strnku');
@define('CLICK_FILE_TO_INSERT', 'Kliknte na soubor, kter chcete vloit:');
@define('SELECT_FILE', 'Vyberte soubor pro vloen:');
@define('MEDIA_FULLSIZE', 'Pln rozmr');
@define('CALENDAR_BOW_DESC', 'Den, uren jako zatek tdne. Default je pondl');
@define('ALLOWS_YOU_BLAHBLAH', 'Vloit odkaz do postrannho bloku administrace weblogu');
@define('CALENDAR', 'Kalend');
@define('SUPERUSER_OPEN_ADMIN', 'Administrace');
@define('SUPERUSER_OPEN_LOGIN', 'Pihlen');
@define('INVERT_SELECTIONS', 'Obrtit vbr');
@define('COMMENTS_DELETE_CONFIRM', 'Jste se jist vymaznm vybranch koment?');
@define('COMMENT_DELETE_CONFIRM', 'Jste si jist vymaznm komente #%d, zapsanho %s?');
@define('DELETE_SELECTED_COMMENTS', 'Vymazat vybran komente');
@define('VIEW_COMMENT', 'Ukzat koment');
@define('VIEW_ENTRY', 'Ukzat zznam');
@define('DELETE_FILE', 'Vymazat soubor s nzvem <b>%s</b>');
@define('ABOUT_TO_DELETE_FILE', 'Chcete vymazat <b>%s</b><br />Jestlie pouvte tento soubor v njakch zznamech, zpsob to nepstupnost odkaz nebo obrzk.<br />Chcete pesto pokraovat?<br /><br />');
@define('TRACKBACK_SENDING', 'Odesln odezvy na URI %s...');
@define('TRACKBACK_SENT', 'Odezva spn');
@define('TRACKBACK_FAILED', 'Odezva nespn: %s');
@define('TRACKBACK_NOT_FOUND', 'URI odezvy neexistuje.');
@define('TRACKBACK_URI_MISMATCH', 'Automaticky zskan URI neodpovd vaemu clovmu.');
@define('TRACKBACK_CHECKING', 'Testvn <u>%s</u> pro mon odezvy...');
@define('TRACKBACK_NO_DATA', 'Cl neobsahuje data');
@define('TRACKBACK_SIZE', 'Clov URI pekroilo max. velikost souboru %s byt.');
@define('VIEWMODE_THREADED', 'Pepnout na vlknov zobrazen');
@define('COMMENTS_VIEWMODE_THREADED', 'Vlknov');
@define('COMMENTS_VIEWMODE_LINEAR', 'Linern');
@define('DISPLAY_COMMENTS_AS', 'Zobrazit komente jako');
@define('ADD_MEDIA_BLAHBLAH', '<b>Pidat soubor do schrnky mdi:</b><p>Zde mete ukldat mediln soubory, nebo urit, kde je zskat z WEBu! Pokud nemte odpovdajc obrzek, <a href="http://images.google.com" target="_blank">hledejte na Google</a> odpov na vai potebu, obvykle se zada :).<p><b>Vyberte metodu:</b><br>');
@define('COMMENTS_FILTER_SHOW', 'Zobrazit');
@define('COMMENTS_FILTER_ALL', 'Ve');
@define('COMMENTS_FILTER_APPROVED_ONLY', 'Pouze povolen');
@define('COMMENTS_FILTER_NEED_APPROVAL', 'ekajc na povolen');
@define('RSS_IMPORT_BODYONLY', 'Uloit cel importovan text do "hlavn" sti, nerozdlovat do "rozen" sti.');
@define('SYNDICATION_PLUGIN_FULLFEED', 'Zobrazit cel lnky vetn rozen sti v RSS kanlu');
@define('MT_DATA_FILE', 'Soubory Movable Type');
@define('FORCE', 'Vnutit');
@define('CREATE_AUTHOR', 'Vytvoit autora \'%s\'.');
@define('CREATE_CATEGORY', 'Vytvoit kategorii \'%s\'.');
@define('MYSQL_REQUIRED', 'Pro proveden tto akce je nutn mt databzi MySQL.');
@define('COULDNT_CONNECT', 'Nebylo mon se spojit s databz MySQL: %s.');
@define('COULDNT_SELECT_DB', 'Nebylo mon vybrat databzi: %s.');
@define('COULDNT_SELECT_USER_INFO', 'Nebylo mon vybrat uivatelsk informace: %s.');
@define('COULDNT_SELECT_CATEGORY_INFO', 'Nebylo mon vybrat informace o kategorii: %s.');
@define('COULDNT_SELECT_ENTRY_INFO', 'Nebylo mon vybrat informace o zznamu: %s.');
@define('COULDNT_SELECT_COMMENT_INFO', 'Nebylo mon vybrat informace o komenti: %s.');
@define('WEEK', 'Tden');
@define('WEEKS', 'Tdny');
@define('MONTHS', 'Msce');
@define('DAYS', 'Dny');
@define('ARCHIVE_FREQUENCY', 'Kalendn krok');
@define('ARCHIVE_FREQUENCY_DESC', 'Kalendn krok mezi prvky seznamu');
@define('ARCHIVE_COUNT', 'Poet prvk v seznamu');
@define('ARCHIVE_COUNT_DESC', 'Celkov poet zobrazench msc, tdn nebo dn');
@define('BELOW_IS_A_LIST_OF_INSTALLED_PLUGINS', 'Ne je seznam instalovanch plugin');
@define('SIDEBAR_PLUGIN', 'postrann plugin');
@define('EVENT_PLUGIN', 'plugin udlosti');
@define('CLICK_HERE_TO_INSTALL_PLUGIN', 'Kliknte a instalujte nov %s');
@define('VERSION', 'verze');
@define('INSTALL', 'Instalovat');
@define('ALREADY_INSTALLED', 'Instalovn');
@define('SELECT_A_PLUGIN_TO_ADD', 'Vyberte plugin, kter chcete instalovat');
@define('INSTALL_OFFSET', 'asov posun serveru');
@define('STICKY_POSTINGS', 'Pilepen zznamy');
@define('INSTALL_FETCHLIMIT', 'Zznamy zobrazen na hlavn strnce');
@define('INSTALL_FETCHLIMIT_DESC', 'Poet zznam, zobrazench na hlavn strnce');
@define('IMPORT_ENTRIES', 'Import dat');
@define('EXPORT_ENTRIES', 'Export zznam');
@define('IMPORT_WELCOME', 'Vtejte v utilit pro import dat');
@define('IMPORT_WHAT_CAN', 'Zde mete importovat zznamy z jinch weblog');
@define('IMPORT_SELECT', 'Vyberte software, ze kterho chcete importovat');
@define('IMPORT_PLEASE_ENTER', 'Vlote data poadovan ne');
@define('IMPORT_NOW', 'Importovat!');
@define('IMPORT_STARTING', 'Start importu...');
@define('IMPORT_FAILED', 'Import se nezdail');
@define('IMPORT_DONE', 'Import spn dokonen');
@define('IMPORT_WEBLOG_APP', 'Weblogov aplikace');
@define('EXPORT_FEED', 'Exportovat pln RSS kanl');
@define('STATUS', 'Stav po importu');
@define('IMPORT_GENERIC_RSS', 'Zkladn RSS import');
@define('ACTIVATE_AUTODISCOVERY', 'Odeslat odezvy na odkazy obsaen v zznamu');
@define('WELCOME_TO_ADMIN', 'Vtejte v Administran sekci Serendipity .');
@define('PLEASE_ENTER_CREDENTIALS', 'Vlote oprvnn.');
@define('ADMIN_FOOTER_POWERED_BY', 'Vytvoeno pomoc Serendipity %s a PHP %s');
@define('INSTALL_USEGZIP', 'Pouijte kompresi gzip');
@define('INSTALL_USEGZIP_DESC', 'Doporuujeme pout kompresi strnek pro jejich urychlen natn');
@define('INSTALL_SHOWFUTURE', 'Zobrazit budouc zznamy');
@define('INSTALL_SHOWFUTURE_DESC', 'Tato volba umon zobrazen budoucch zznam blogu. Defaultn jsou skryt a budou zobrazeny a v ase jejich vydn.');
@define('INSTALL_DBPERSISTENT', 'Pout trval pipojen');
@define('INSTALL_DBPERSISTENT_DESC', 'Umonit trval pipojen k databzi, vce <a href="http://php.net/manual/features.persistent-connections.php" target="_blank">zde</a>. Bn to nen doporueno');
@define('NO_IMAGES_FOUND', 'dn obrzky');
@define('PERSONAL_SETTINGS', 'Osobn nastaven');
@define('REFERER', 'Odbratel');
@define('NOT_FOUND', 'Nen obsaen');
@define('NOT_WRITABLE', 'Nezapisovateln');
@define('WRITABLE', 'Zapisovateln');
@define('PROBLEM_DIAGNOSTIC', 'Byly diagnostikovny problmy, take nelze pokraovat v instalaci, dokud nebudou odstranny');
@define('SELECT_INSTALLATION_TYPE', 'Vyberte typ instalace');
@define('WELCOME_TO_INSTALLATION', 'Vtejte v instalaci Serendipity');
@define('FIRST_WE_TAKE_A_LOOK', 'Nejdve se podvme na vae zkladn nastaven a zkusme diagnostikovat ppadn problmy');
@define('ERRORS_ARE_DISPLAYED_IN', 'Chyby budou zobrazeny %s, doporuen %s a spch %s');
@define('RED', 'erven');
@define('YELLOW', 'lut');
@define('GREEN', 'zelen');
@define('PRE_INSTALLATION_REPORT', 'Serendipity v%s - pedinstalan zprva');
@define('RECOMMENDED', 'Doporueno');
@define('ACTUAL', 'Aktuln');
@define('PHPINI_CONFIGURATION', 'konfigurace php.ini');
@define('PHP_INSTALLATION', 'Instalace PHP');
@define('THEY_DO', 'they do');
@define('THEY_DONT', 'they don\'t');
@define('SIMPLE_INSTALLATION', 'Jednoduch instalace');
@define('EXPERT_INSTALLATION', 'Expertn instalace');
@define('COMPLETE_INSTALLATION', 'Kompletn instalace');
@define('WONT_INSTALL_DB_AGAIN', 'nechci znovu instalovat databzi');
@define('CHECK_DATABASE_EXISTS', 'Kontrola, jestli databze a tabulky opravdu existuj');
@define('CREATING_PRIMARY_AUTHOR', 'Vytvoen hlavnho autora \'%s\'');
@define('SETTING_DEFAULT_TEMPLATE', 'Nastaven defaultnho vzoru');
@define('INSTALLING_DEFAULT_PLUGINS', 'Instalace defaultnch plugin');
@define('SERENDIPITY_INSTALLED', 'Serendipity byl spn nainstalovn');
@define('VISIT_BLOG_HERE', 'Zde se pepnete do svho novho weblogu');
@define('THANK_YOU_FOR_CHOOSING', 'Dkujeme za volbu Serendipity');
@define('ERROR_DETECTED_IN_INSTALL', 'Pi instalaci byla detekovna chyba');
@define('OPERATING_SYSTEM', 'Operan systm');
@define('WEBSERVER_SAPI', 'Webserver SAPI');
@define('IMAGE_ROTATE_LEFT', 'Otoit o 90 stup doleva');
@define('IMAGE_ROTATE_RIGHT', 'Otoit o 90 stup doprava');
@define('TEMPLATE_SET', '\'%s\' byl nastaven jako defaultn vzor (template)');
@define('SEARCH_ERROR', 'Funkce vyhledvn nepracovala podle oekvn. Poznmka pro administrtora blogu: Mohlo to bt zpsobeno neptomnost pslunch index v databzi. Uivatelsk et v databzi MySQL mus bt oprvnn vykonat tento dotaz: <pre>CREATE FULLTEXT INDEX entry_idx on %sentries (title,body,extended)</pre> Specifick chyba vrcen databz byla: <pre>%s</pre>');
@define('EDIT_THIS_CAT', 'Editace "%s"');
@define('CATEGORY_REMAINING', 'Vymazat kategorii a pemstit zznamy do kategorie');
@define('CATEGORY_INDEX', 'Ne je seznam kategori, kter met pout k vaemu zznamu');
@define('NO_CATEGORIES', 'dn kategorie');
@define('RESET_DATE', 'Resetovat datum');
@define('RESET_DATE_DESC', 'Kliknte a resetujte datum na aktuln');
@define('PROBLEM_PERMISSIONS_HOWTO', 'Oprvnn me bt nastaveno s pouitm povelu: `<em>%s</em>` v adresi, nebo nastavenm pomoc FTP programu');
@define('WARNING_TEMPLATE_DEPRECATED', 'Varovn: V vzor pouv nepovolenou metodu, je-li to mon, provete aktualizaci');
@define('ENTRY_PUBLISHED_FUTURE', 'Tento zznam jet nen publikovn.');
@define('ENTRIES_BY', 'Zznamy od %s');
@define('PREVIOUS', 'Pedchoz');
@define('NEXT', 'Dal');
@define('APPROVE', 'Povolit');
@define('DO_MARKUP_DESCRIPTION', 'Pevst znaky na text (smajlky, zkratky *, /, _, ...). Vypnut tto volby zajist uloen HTML kd v textu.');
@define('CATEGORY_ALREADY_EXIST', 'Kategorie nazvan "%s" skuten existuje');
@define('IMPORT_NOTES', 'Poznmka:');
@define('ERROR_FILE_FORBIDDEN', 'Nejste oprvnn nahrvat soubory s aktivnm obsahem');
@define('ADMIN', 'Administrace');
@define('ADMIN_FRONTPAGE', 'Hlavn strnka');
@define('QUOTE', 'Citace');
@define('IFRAME_SAVE', 'Serendipity ukld v zznam, vytv odezvy a zajiuje mon XML-RPC spojen. Me to chvli trvat...');
@define('IFRAME_SAVE_DRAFT', 'Koncept tohoto zznamu byl uloen');
@define('IFRAME_PREVIEW', 'Serendipity nyn vytv nhled vaeho zznamu...');
@define('IFRAME_WARNING', 'V prohle nepodporuje iframe. Otevete soubor serendipity_config.inc.php a nastavte promnnou $serendipity[\'use_iframe\'] na FALSE.');
@define('NONE', 'nic');
@define('USERCONF_CAT_DEFAULT_NEW_ENTRY', 'Zkladn nastaven pro nov zznamy');
@define('UPGRADE', 'Aktualizace');
@define('UPGRADE_TO_VERSION', 'Aktualizace na verzi %s');
@define('DELETE_DIRECTORY', 'Vymazat adres');
@define('DELETE_DIRECTORY_DESC', 'Chcete vymazat obsah adrese, obsahujc mediln soubory, kter mohou bt pouvny ve vaich zznamech.');
@define('FORCE_DELETE', 'Vymazat VECHNY soubory v adresi, vetn tch, kter nejsou vytvoeny pomoc Serendipity');
@define('CREATE_DIRECTORY', 'Vytvoit adres');
@define('CREATE_NEW_DIRECTORY', 'Vytvoit nov adres');
@define('CREATE_DIRECTORY_DESC', 'Zde mete vytvoit adres pro ukldn medilnch soubor. Zvolte nzev adrese a ppadn nadzen adres.');
@define('BASE_DIRECTORY', 'Zkladn adres');
@define('USERLEVEL_EDITOR_DESC', 'Autor');
@define('USERLEVEL_CHIEF_DESC', 'Redaktor');
@define('USERLEVEL_ADMIN_DESC', 'Administrtor');
@define('USERCONF_USERLEVEL', 'rove');
@define('USERCONF_USERLEVEL_DESC', 'Tato rove uruje prva uivatele weblogu.');
@define('USER_SELF_INFO', 'Pihlen jako %s (%s)');
@define('ADMIN_ENTRIES', 'Zznamy');
@define('RECHECK_INSTALLATION', 'Pekontrolovat instalaci');
@define('IMAGICK_EXEC_ERROR', 'Nelze spustit: "%s", chyba: %s, vrac promnnou: %d');
@define('INSTALL_OFFSET_DESC', 'Vlote poet hodin mezi asem serveru (aktuln: %clock%) a va asovou znou');
@define('UNMET_REQUIREMENTS', 'Nesplnn poadavky: %s');
@define('CHARSET', 'Znakov sada');
@define('AUTOLANG', 'Pout jazyk prohlee jako defaultn');
@define('AUTOLANG_DESC', 'Zapnutm tto volby urte, e jazyk prohlee bude pevzat jako zkladn pro uivatelsk rozhran a pro zznamy.');
@define('INSTALL_AUTODETECT_URL', 'Autodetekce pouit HTTP hostitelsk adresy');
@define('INSTALL_AUTODETECT_URL_DESC', 'Pi volb "Ano" bude Serendipity pedpokldat, e HTTP adresa hostitele, pouit nvtvnkem, je vae zkladn nastaven URL. Zapnut umon pouvn rznch domn k pstupu na vae strnky, a pouit tto jedn domny pro vechny odkazy ke sledovn zmn na strnkch.');
@define('CONVERT_HTMLENTITIES', 'Zkusit automatickou konverzi HTML entit?');
@define('EMPTY_SETTING', 'Nespecifikoval jste platnou hodnotu pro "%s"!');
@define('USERCONF_REALNAME', 'Skuten jmno');
@define('USERCONF_REALNAME_DESC', 'Pln jmno autora. Toto jmno uvid teni');
@define('HOTLINK_DONE', 'Soubor pipojen odkazem.<br />Hotovo.');
@define('ENTER_MEDIA_URL_METHOD', 'Zpsob pipojen:');
@define('ADD_MEDIA_BLAHBLAH_NOTE', 'Poznmka: Pokud zvolte odkaz na server, ujistte se, e mte potebn prva, nebo e jde o v web. Odkazy vm umon vyuvat obrzky z jinch ne mstnch zdroj.');
@define('MEDIA_HOTLINKED', 'odkazovn');
@define('FETCH_METHOD_IMAGE', 'Nahrn na server');
@define('FETCH_METHOD_HOTLINK', 'Odkaz na server');
@define('DELETE_HOTLINK_FILE', 'Vymazn odkazovan soubor <b>%s</b>');
@define('SYNDICATION_PLUGIN_SHOW_MAIL', 'Zobrazovat e-mailov adresy?');
@define('IMAGE_MORE_INPUT', 'Pidat vce obrzk'); 
@define('BACKEND_TITLE', 'Dal informace v konfiguran obrazovce pluginu');
@define('BACKEND_TITLE_FOR_NUGGET', 'Zde mete definovat svj etzec, kter bude zobrazen v konfiguran obrazovce pluginu spolen s popisem pluginu HTML Nugget. Kdy mte nkolik HTML nugget s przdnm tittle, toto vm pome je rozliit.'); 
@define('CATEGORIES_ALLOW_SELECT', 'Povolit nvtvnkm zobrazit vce kategori najednou?');
@define('CATEGORIES_ALLOW_SELECT_DESC', 'Jestlie je tato volba povolena, bude v tomto postrannm pluginu hned vedle kad kategorie zakrtvac oknko. Uivatel mohou tyto boxy zakrtnout a vidt jen pspvky patc do tohoto vbru.'); 
@define('PAGE_BROWSE_PLUGINS', 'Strana %s z %s, celkem %s plugin.');
@define('INSTALL_CAT_PERMALINKS', 'Trval odkazy');
@define('INSTALL_CAT_PERMALINKS_DESC', 'Definuje rzn vzory  URL patterns pro definici trvalch odkaz (permanent links) ve vaem blogu. Doporuujeme pout defaultn nastaven; pokud ne, mli byste zkusit pout hodnotu %id% tam, kde je to mon, abyste pedeli dotazm do databze pi hledn clov URL.');
@define('INSTALL_PERMALINK', 'Struktura URL trvalch odkaz');
@define('INSTALL_PERMALINK_DESC', 'Zde mete definovat relativn strukturu URL, kde zatek je vae base URL, z n mohou bt  pspvky dostupn. Mete pout promnn  %id%, %title%, %day%, %month%, %year% a jakkoli jin znaky.');
@define('INSTALL_PERMALINK_AUTHOR', 'Struktura URL autor');
@define('INSTALL_PERMALINK_AUTHOR_DESC', 'Zde mete definovat relativn strukturu URL, kde zatek je vae base URL, z n mohou bt dostupn pspvky uritch autor.  Mete pout promnn %id%, %realname%, %username%, %email% a jakkoli jin znaky.');
@define('INSTALL_PERMALINK_CATEGORY', 'Struktura URL kategori');
@define('INSTALL_PERMALINK_CATEGORY_DESC', 'Zde mete definovat relativn strukturu URL, kde zatek je vae base URL, z n mohou bt dostupn urit kategorie. Mete pout promnn  %id%, %name%, %description% a jakkoli jin znaky.');
@define('INSTALL_PERMALINK_FEEDCATEGORY', 'Struktura URL trvalch odkaz kategori RSS');
@define('INSTALL_PERMALINK_FEEDCATEGORY_DESC', 'Zde mete definovat relativn strukturu URL, kde zatek je vae base URL, z n mohou bt dostupn  RSS kanly z uritch kategori. Mete pout promnn %id%, %name%, %description% a jakkoli jin znaky.');
@define('INSTALL_PERMALINK_ARCHIVESPATH', 'Cesta k archivm');
@define('INSTALL_PERMALINK_ARCHIVEPATH', 'Cesta k archivu');
@define('INSTALL_PERMALINK_CATEGORIESPATH', 'Cesta ke kategorim');
@define('INSTALL_PERMALINK_UNSUBSCRIBEPATH', 'Cesta k odhlen koment');
@define('INSTALL_PERMALINK_DELETEPATH', 'Cesta pro smazn koment');
@define('INSTALL_PERMALINK_APPROVEPATH', 'Cesta ke schvlen koment');
@define('INSTALL_PERMALINK_FEEDSPATH', 'Cesta k RSS');
@define('INSTALL_PERMALINK_PLUGINPATH', 'Cesta k jednotlivmu pluginu');
@define('INSTALL_PERMALINK_ADMINPATH', 'Cesta k adminu');
@define('INSTALL_PERMALINK_SEARCHPATH', 'Cesta k vyhledvn');
@define('INSTALL_CAL', 'Typ kalende');
@define('INSTALL_CAL_DESC', 'Vyberte formt kalende');
@define('REPLY', 'Odpov');
@define('USERCONF_GROUPS', 'lenstv ve skupinch');
@define('USERCONF_GROUPS_DESC', 'Tento uivatel je len nsledujcch skupin. lenstv ve vce skupinch je mon.');
@define('MANAGE_GROUPS', 'Upravuj skupiny');
@define('DELETED_GROUP', 'Skupina #%d %s smazna.');
@define('CREATED_GROUP', 'Nov skupina %s byla vytvoena');
@define('MODIFIED_GROUP', 'Vlastnosti skupiny %s byly zmnny');
@define('GROUP', 'Skupina');
@define('CREATE_NEW_GROUP', 'Vytvoit novou skupinu');
@define('DELETE_GROUP', 'Chystte se smazat skupinu #%d %s. Myslte to vn?');
@define('USERLEVEL_OBSOLETE', 'UPOZORNN: Atribut rove uivatele (userlevel) je nyn pouvn jen kvli zptn kompatibilit s pluginy a autorizaci. Uivatelsk prva jsou nyn zena pomoc lenskch skupin!');
@define('SYNDICATION_PLUGIN_FEEDBURNERID', 'FeedBurner ID');
@define('SYNDICATION_PLUGIN_FEEDBURNERID_DESC', 'ID feedu, kter chcete publikovat');
@define('SYNDICATION_PLUGIN_FEEDBURNERIMG', 'FeedBurner image');
@define('SYNDICATION_PLUGIN_FEEDBURNERIMG_DESC', 'Nzev obrzku, kter se m zobrazit (nebo przdn pro poitadlo), umstn na  feedburner.com, nap: fbapix.gif');
@define('SYNDICATION_PLUGIN_FEEDBURNERTITLE', 'FeedBurner title');
@define('SYNDICATION_PLUGIN_FEEDBURNERTITLE_DESC', 'Title (je-li), kter se m zobrazit u obrzku');
@define('SYNDICATION_PLUGIN_FEEDBURNERALT', 'FeedBurner image text');
@define('SYNDICATION_PLUGIN_FEEDBURNERALT_DESC', 'Text (je-li) kter se m zobrazit pi najet na obrzek');
@define('SEARCH_TOO_SHORT', 'Vyhledvac dotaz mus bt del ne 3 znaky. Ke kratm slovm mete zkusit pidat *, jako: s9y*, abyste  vyhledvn pimli pracovat s kratmi slovy.');
@define('INSTALL_DBPORT', 'Database port');
@define('INSTALL_DBPORT_DESC', 'Port pouit pro spojen k vaemu databzovmu serveru');
@define('PLUGIN_GROUP_FRONTEND_EXTERNAL_SERVICES', 'Viditeln (Frontend): Extern sluby');
@define('PLUGIN_GROUP_FRONTEND_FEATURES', 'Viditeln (Frontend): Dal monosti');
@define('PLUGIN_GROUP_FRONTEND_FULL_MODS', 'Viditeln (Frontend): pln mody');
@define('PLUGIN_GROUP_FRONTEND_VIEWS', 'Viditeln (Frontend): Zobrazen/filtry');
@define('PLUGIN_GROUP_FRONTEND_ENTRY_RELATED', 'Viditeln (Frontend): Pluginy pro pspvky');
@define('PLUGIN_GROUP_BACKEND_EDITOR', 'Provozn (Backend): Editor');
@define('PLUGIN_GROUP_BACKEND_USERMANAGEMENT', 'Provozn (Backend): zen uivatel');
@define('PLUGIN_GROUP_BACKEND_METAINFORMATION', 'Provozn (Backend): Meta informace');
@define('PLUGIN_GROUP_BACKEND_TEMPLATES', 'Provozn (Backend): Templates - ablony vzhledu');
@define('PLUGIN_GROUP_BACKEND_FEATURES', 'Provozn (Backend): Dal monosti');
@define('PLUGIN_GROUP_IMAGES', 'Obrzky');
@define('PLUGIN_GROUP_ANTISPAM', 'Antispam');
@define('PLUGIN_GROUP_MARKUP', 'Markup - textov znaky');
@define('PLUGIN_GROUP_STATISTICS', 'Statistiky');
@define('PERMISSION_PERSONALCONFIGURATION', 'osobnKonfigurace: Pstup k osobn konfiguraci');
@define('PERMISSION_PERSONALCONFIGURATIONUSERLEVEL', 'osobnKonfiguraceroveUivatele: Zmnit rove uivatele (level)');
@define('PERMISSION_PERSONALCONFIGURATIONNOCREATE', 'osobnKonfiguraceNeNov: Zmnit "zkaz novch pspvk"');
@define('PERMISSION_PERSONALCONFIGURATIONRIGHTPUBLISH', 'osobnKonfiguracePrvoPublikovat: Zmnit prvo na publikovn pspvk');
@define('PERMISSION_SITECONFIGURATION', 'webKonfigurace: Konfigurace  pstupu');
@define('PERMISSION_BLOGCONFIGURATION', 'blogKonfigurace: Konfigurace pstupu k  blogu');
@define('PERMISSION_ADMINENTRIES', 'adminPspvky: Administrace pspvk');
@define('PERMISSION_ADMINENTRIESMAINTAINOTHERS', 'admindrbaPspvkOstatnch: Administrace pspvk ostatnch uivatel');
@define('PERMISSION_ADMINIMPORT', 'adminImport: Import pspvk');
@define('PERMISSION_ADMINCATEGORIES', 'adminKategorie: Administrace kategori');
@define('PERMISSION_ADMINCATEGORIESMAINTAINOTHERS', 'admindrbaKategoriOstatnch: Administrace kategori ostatnch uivatel');
@define('PERMISSION_ADMINCATEGORIESDELETE', 'adminMaznKategori: Smazat kategorie');
@define('PERMISSION_ADMINUSERS', 'adminUivatel: Administrace uivatel');
@define('PERMISSION_ADMINUSERSDELETE', 'adminMaznUivatel: Smazat uivatele');
@define('PERMISSION_ADMINUSERSEDITUSERLEVEL', 'adminZmnarovnUivatele: Zmna rovn uivatele');
@define('PERMISSION_ADMINUSERSMAINTAINSAME', 'adminUivatelStejnSkupiny: Administrace uivatel ve stejn skupin');
@define('PERMISSION_ADMINUSERSMAINTAINOTHERS', 'adminUivatelJinSkupiny: Administrace uivatel v jinch skupinch');
@define('PERMISSION_ADMINUSERSCREATENEW', 'adminNovUivatel: Zakldat nov uivatele');
@define('PERMISSION_ADMINUSERSGROUPS', 'adminUivatelskSkupiny: Administrace skupin uivatel');
@define('PERMISSION_ADMINPLUGINS', 'adminPluginy: Administrace plugin');
@define('PERMISSION_ADMINPLUGINSMAINTAINOTHERS', 'admindrbaPluginOstatnch: Administrace plugin ostatnch uivatel');
@define('PERMISSION_ADMINIMAGES', 'adminObrzky: Administrace soubor  media');
@define('PERMISSION_ADMINIMAGESDIRECTORIES', 'adminAdreseObrzk: Administrace adres pro media');
@define('PERMISSION_ADMINIMAGESADD', 'adminPidatObrzek: Pidvn novch soubor medi');
@define('PERMISSION_ADMINIMAGESDELETE', 'adminSmazatObrzek: Mazn soubor medi');
@define('PERMISSION_ADMINIMAGESMAINTAINOTHERS', 'admindrbaObrzkOstatn: Administrace soubor medi ostatnch uivatel');
@define('PERMISSION_ADMINIMAGESVIEW', 'adminProhlenObrzk: Prohlen soubor medi');
@define('PERMISSION_ADMINIMAGESSYNC', 'adminSynchroObrzk: Sync thumbnail');
@define('PERMISSION_ADMINCOMMENTS', 'adminKomente: Administrace koment');
@define('PERMISSION_ADMINTEMPLATES', 'adminTemplate: Administrace ablon (template)');
@define('INSTALL_BLOG_EMAIL', 'E-Mail pro blog');
@define('INSTALL_BLOG_EMAIL_DESC', 'Toto nastav E-Mailovou adresu, kter je pouita v poli "From"- (od) pro odchoz e-maily. Nastavte si tuto adresu tak, aby byla rozpoznna mailovm serverem pouvanm vam webhosterem - mnoho mailserver odmt potu, kter m neznmou From-addresu (adr odesilatele).');
@define('CATEGORIES_PARENT_BASE', 'Zobrazit jen kategorie nie ...');
@define('CATEGORIES_PARENT_BASE_DESC', 'Mete vybrat rodiovskou kategorii, take budou zobrazeny jen jej ni kategori.');
@define('CATEGORIES_HIDE_PARALLEL', 'Skrt kategorie, kter nejsou soust stromu kategori');
@define('CATEGORIES_HIDE_PARALLEL_DESC', 'Jestlie chcete skrt kategorie, kter jsou st jinho stromu kategori, muste tohle povolit. Tato monost se nejlpe  pouije ve spojen s multi-blogem a pluginem  "Properties/Templates of categories".');
@define('PERMISSION_ADMINIMAGESVIEWOTHERS', 'adminProhlenObrzkOstatn: Prohlen medi ostatnch uivatel');
@define('CHARSET_NATIVE', 'Nrodn');
@define('INSTALL_CHARSET', 'Volba znakov sady - Charset');
@define('INSTALL_CHARSET_DESC', 'Zde mete volit mezi UTF-8 nebo nrodn (ISO, EUC, ...) znakovou sadou. Nkter jazyky maj jen peklady UTF-8, take nastaven znakov sady na nrodn nem dn inek. UTF-8 se doporuuje pro nov instalace. Nemte toto nastaven, jestlie jste ji  napsali pspvky se specilnmi (nrodnmi) znaky - mohlo by zpsobit poruen textu. Pette si o tomto problmu vce na  http://www.s9y.org/index.php?node=46 .');
@define('CALENDAR_ENABLE_EXTERNAL_EVENTS', 'Povolit Plugin API hook');
@define('CALENDAR_EXTEVENT_DESC', 'Jestlie je toto povoleno, mohou se pluginy napojovat na kalend a zvrazovat sv vlastn udlosti. Povolte jen kdy mte pluginy, kter toto potebuj, jinak to jen sniuje vkon.');
@define('XMLRPC_NO_LONGER_BUNDLED', 'XML-RPC API Interface na Serendipity ji nen pibaleno  kvli pokraujcm bezpenostnm problmm s tmhle API a protoe ho moc lid nepouv. Proto muste nainstalovat plugin XML-RPC, kdy chcete  XML-RPC API pouvat. URL, kter se pouije ve va aplikaci, se nezmn - hned po instalaci pluginu budete moci API pouvat.');
@define('PERM_READ', 'Prvo na ten');
@define('PERM_WRITE', 'Prvo na zpis');

@define('PERM_DENIED', 'Pstup odepen.');
@define('INSTALL_ACL', 'Aplikovat prva na ten pro kategorie');
@define('INSTALL_ACL_DESC', 'Pokud je povoleno, budou na kategorie aplikovna nastaven prv pro skupiny uivatel, kdy si pihlen uivatel budou prohlet v blog. Nen-li povoleno, prva na ten pro kategorie nejsou aplikovna,  a  zlepuje se rychlost blogu. Jestlie nechcete mt prva pro ten pro rzn uivatele,  toto nastaven zakate.');
@define('PLUGIN_API_VALIDATE_ERROR', 'Syntax konfigurace je chybn pro volbu "%s". Vyaduje obsah typu "%s".');
@define('USERCONF_CHECK_PASSWORD', 'Star heslo');
@define('USERCONF_CHECK_PASSWORD_DESC', 'Jestlie zmnte  heslo v polku ve, muste do tohoto pole zadat souasn heslo.');
@define('USERCONF_CHECK_PASSWORD_ERROR', 'Nezadali jste sprvn star heslo a nejste oprvnni heslo zmnit. Vae nastaven nebylo uloeno.');
@define('ERROR_XSRF', 'V prohle nezaslal platn  HTTP-Referrer string. To mohlo bt zpsobeno bu patn nastavenm prohleem/proxy nebo  Cross Site Request Forgery (XSRF), kter je na vs namen. Poadovan akce nemohla bt dokonena.');
@define('INSTALL_PERMALINK_FEEDAUTHOR_DESC', 'Zde mete definovat relativn strukturu URL, kde zatek je vae base URL, z n mohou bt bt dostupn RSS kanly od uritch uivatel. Mete pout promnn   %id%, %realname%, %username%, %email% a jakkoli jin znaky.');
@define('INSTALL_PERMALINK_FEEDAUTHOR', 'Permalink RSS-Feed Author URL structure');
@define('INSTALL_PERMALINK_AUTHORSPATH', 'Cesta k autorm');
@define('AUTHORS', 'Autoi');
@define('AUTHORS_ALLOW_SELECT', 'Povolit nvtvnkm vybrat vce autor najednou?');
@define('AUTHORS_ALLOW_SELECT_DESC', 'Jestlie je tato volba povolena, bude u kadho autora umstno zatrhvac oknko. Uivatel mohou zvolit vce autor  a vidt pspvky, kter vyhovuj jejich vbru');
@define('AUTHOR_PLUGIN_DESC', 'Zobrazit seznam autor');
@define('CATEGORY_PLUGIN_TEMPLATE', 'Povolit Smarty-Templates?');
@define('CATEGORY_PLUGIN_TEMPLATE_DESC', 'Je-li tato monost povolena, bude plugin pro vpis kategori vyuvat monost  Smarty-Templating. Kdy tohle povolte, mete mnit layout pes ablonu "plugin_categories.tpl". Povolen thle volby me zhorit vkon, take pokud nechcete dlat pravy pro jednotliv kategorie, nechte to zakzan.');
@define('CATEGORY_PLUGIN_SHOWCOUNT', 'Zobrazit poet pspvk na kategorii? ');
@define('AUTHORS_SHOW_ARTICLE_COUNT', 'Zobrazit poet lnk u jmna autora?');
@define('AUTHORS_SHOW_ARTICLE_COUNT_DESC', 'Je-li tato volba povolena, je vedle jmna autora zobrazen v zvorce poet jeho pspvk.');
@define('CUSTOM_ADMIN_INTERFACE', 'Je upraven prosted pro administraci');

@define('COMMENT_NOT_ADDED', 'V koment nemohl bt pidn, protoe komente k tomuto pspvku byly zakzny, zadali jste patn data nebo byl v koment zachycen antispamem.');
@define('INSTALL_TRACKREF', 'Povolit  referrer tracking?');
@define('INSTALL_TRACKREF_DESC', 'Povolen referrer tracking vm uke, kter weby odkazuj na vae lnky. Dnes je to asto zneuvno pro spam, take to mete zakzat, chcete-li.');
@define('CATEGORIES_HIDE_PARENT', 'Skrt zvolenou rodiovskou kategorii?');
@define('CATEGORIES_HIDE_PARENT_DESC', 'Jestlie omezte vpis kategori na specifickou kategorii,  standardn bude  na vstupu rodiovsk kategorie zobrazena. Kdy tuto monost zakete, nzev rodiovsk kategorie nebude zobrazen.');
@define('WARNING_NO_GROUPS_SELECTED', 'Varovn: Nezvolili jste si lenstv v dn skupin. To by vs vylouilo z zen prv uivatelskch skupin, a proto vae lenstv ve skupin nebude zmnno.');
@define('INSTALL_RSSFETCHLIMIT', 'lnky, kter se maj zobrazit v RSS Feedu');
@define('INSTALL_RSSFETCHLIMIT_DESC', 'Poet lnk, kter se m zobrazit na kad strnce  v RSS Feedu.');
@define('INSTAL_DB_UTF8', 'Povolit DB-charset conversion');
@define('INSTAL_DB_UTF8_DESC', 'Vyvol dotaz MySQL "SET NAMES", aby se zjistila poadovan znakov sada pro databzi. Zapnte to nebo vypnte, pokud se vm na blogu objevuj  podivn znaky.');
@define('ONTHEFLYSYNCH', 'Povolit synchronizaci medi za bhu (on the fly)');
@define('ONTHEFLYSYNCH_DESC', 'Pokud je to povoleno, Serendipity bude porovnvat databzi medi se soubory uloenmi na serveru a bude synchronizovat obsah databze a adrese.');
@define('USERCONF_CHECK_USERNAME_ERROR', 'Jmno uivatele neme bt przdn.');
@define('FURTHER_LINKS', 'Dal odkazy');
@define('FURTHER_LINKS_S9Y', 'Serendipity Homepage');
@define('FURTHER_LINKS_S9Y_DOCS', 'Serendipity Documentation');
@define('FURTHER_LINKS_S9Y_BLOG', 'Official Blog');
@define('FURTHER_LINKS_S9Y_FORUMS', 'Forums');
@define('FURTHER_LINKS_S9Y_SPARTACUS', 'Spartacus');
@define('COMMENT_IS_DELETED', '(Koment odstrann)');

@define('CURRENT_AUTHOR', 'Aktuln autor');

@define('WORD_NEW', 'Nov');
@define('SHOW_MEDIA_TOOLBAR', 'Ukzat litu nstroj v okn vbru medi?');
@define('MEDIA_KEYWORDS', 'Media - klov slova');
@define('MEDIA_KEYWORDS_DESC', 'Zadejte seznam slov oddlench  ";" kter chcete pout jako peddefonovan klov slova pro poloky v medich.');
@define('MEDIA_EXIF', 'Importovat EXIF/JPEG  data obrzku');
@define('MEDIA_EXIF_DESC', 'Je-li povoleno, existujc EXIF/JPEG metadata obrzk budou parsovna a uloena v databzi, aby je bylo mono zobrazit v galerii medi.');
@define('MEDIA_PROP', 'Vlastnosti media');


@define('GO_ADD_PROPERTIES', 'Zadej vlastnosti');
@define('MEDIA_PROPERTY_DPI', 'DPI');
@define('MEDIA_PROPERTY_COPYRIGHT', 'Copyright');
@define('MEDIA_PROPERTY_COMMENT1', 'Krtk koment');
@define('MEDIA_PROPERTY_COMMENT2', 'Dlouh koment');
@define('MEDIA_PROPERTY_TITLE', 'Titulek');
@define('MEDIA_PROP_DESC', 'Zadejte seznam pol vlastnost oddlench  ";" , kter chcete definovat pro kad souor v medich');
@define('MEDIA_PROP_MULTIDESC', '(Za kadou poloku mete pidat ":MULTI", co bude indikovat, e tato poloka bude obsahovat dlouh text msto jen nkolika znak)');

@define('STYLE_OPTIONS_NONE', 'Toto tma/styl nem specifick volby. Pokud chcete vdt, jak mete pro svoje ablony nastavit specifick volby, tte Technical Documentation na www.s9y.org  "Configuration of Theme options".');
@define('STYLE_OPTIONS', 'Volby pro tma/stylu');

@define('PLUGIN_AVAILABLE_COUNT', 'Celkem: %d plugin.');

@define('SYNDICATION_RFC2616', 'Aktivovat strict RFC2616 RSS-Feed compliance');
@define('SYNDICATION_RFC2616_DESC', 'Kdy neaktivujete  RFC2616, znamen to, e vechny podmnn GETy na Serendipity vrt pspvky, kter byly modifikovny od asu poslednho poadavku. Kdy tohle nastavte na  "false", vai nvtvnci dostanou vechny lnky od svho poslednho poadavku, co se povauje za dobrou vc. Avak nkte agenti jako  Planet funguj divn, kdy tohle nastane a taky to poruuje  RFC2616. Take kdy nastavte tuto volbu na  "TRUE", budete vyhovovat RFC ale nvtvnkm   mohou ve  tekch  bhem przdnin zmizet pspvky. V kadm ppad, bu to vad agregtorm jako je  Planet, nebo to vad nvtvnkm blogu. Kdy se vyskytnou stnosti z kterkoli strany, mete tuhle volbu pepnout.  Reference: <a href="https://sourceforge.net/tracker/index.php?func=detail&amp;aid=1461728&amp;group_id=75065&amp;atid=542822" target="_blank" rel="nofollow">SourceForge</a>');
@define('MEDIA_PROPERTY_DATE', 'Asociovan datum');
@define('MEDIA_PROPERTY_RUN_LENGTH', 'Run-Length');
@define('FILENAME_REASSIGNED', 'Automaticky pidlen nov jmno souboru: %s');
@define('MEDIA_UPLOAD_SIZE', 'Max. velikost uploadvoanho souboru');
@define('MEDIA_UPLOAD_SIZE_DESC', 'Zadejte maximln velikost pro uploadovan (nahrvan) soubory v bytech. Toto nastaven me bt  pepsno nastavenm serveru v php.ini: upload_max_filesize, post_max_size, max_input_time maj pednost ped touto volbou. Przdn etzec znamen, e se pouije limit serveru.');
@define('MEDIA_UPLOAD_SIZEERROR', 'Chyba: Nemete uploadovat soubory vt ne  %s byt!');
@define('MEDIA_UPLOAD_MAXWIDTH', 'Max. ka obrzk pro upload');
@define('MEDIA_UPLOAD_MAXWIDTH_DESC', 'Zadejte maximln ku pro uploadovan obrzky v pixelech.');
@define('MEDIA_UPLOAD_MAXHEIGHT', 'Max. vka obrzku pro upload');
@define('MEDIA_UPLOAD_MAXHEIGHT_DESC', 'Zadejte maximln vku v pixelech pro uploadovan obrzky.');
@define('MEDIA_UPLOAD_DIMERROR', 'Chyba: Nemete uploadovat soubory obrzk vt ne  %s x %s pixel!');

@define('MEDIA_TARGET', 'Cl odkazu');
@define('MEDIA_TARGET_JS', 'Popup okno (pomoc JavaScriptu, pizpsobiteln velikost)');
@define('MEDIA_ENTRY', 'Samostatn pspvek');
@define('MEDIA_TARGET_BLANK', 'Popup okno (pomoc target=_blank)');

@define('MEDIA_DYN_RESIZE', 'Povolit dynamickou zmnu velikosti obrzk?');
@define('MEDIA_DYN_RESIZE_DESC', 'Je-li povoleno, me  media selector vracet obrzky v jakkoli poadovan velikosti pes promnnou  GET. Vsledky jsou keovny, a tak se me vytvoit velk soubor, jestlie to intenzivn pouvte.');

@define('MEDIA_DIRECTORY_MOVED', 'Adrese a soubory byly spn pesunuty do  %s');
@define('MEDIA_DIRECTORY_MOVE_ERROR', 'Adrese a soubory nemohly bt pesunuty do  %s!');
@define('MEDIA_DIRECTORY_MOVE_ENTRY', 'V Ne-MySQL databzi nen iterace po pspvcch a nahrazen star adresy pvodnho adrese novou URL mon. Budete muset pspvky run editovat a ty adresy upravit. Ale pod jet mete adres pesunout zptky tam kde byl, jestli je to pro vs moc otravn.');
@define('MEDIA_DIRECTORY_MOVE_ENTRIES', 'URL pesunutho adrese pesunuto v   %s pspvcch.');
@define('PLUGIN_ACTIVE', 'Aktivn');
@define('PLUGIN_INACTIVE', 'Neaktivn');
@define('PREFERENCE_USE_JS', 'Povolit pouit advanced JS?');
@define('PREFERENCE_USE_JS_DESC', 'Je-li toto povoleno, budou povoleny sekce s advanced JavaScript, aby se zlepila pouitelnost. Nap v sekci pro konfiguraci plugin mete pro peskldn plugin pout drag and drop (thnout my).');

@define('PREFERENCE_USE_JS_WARNING', '(Tato strnka pouv advanced JavaScripting. Jestlie mte problmy s fungovnm, zakate prosm pouvn  advanced JS ve svm osobnm nastaven nebo zakate javascript v prohlei.)');


@define('INSTALL_PERMALINK_COMMENTSPATH', 'Cesta ke komentm');
@define('PERM_SET_CHILD', 'Nastavte shodn prva pro vechny podzen adrese');
@define('PERMISSION_FORBIDDEN_PLUGINS', 'Zakzan pluginy');
@define('PERMISSION_FORBIDDEN_HOOKS', 'Zakzan udlosti');
@define('PERMISSION_FORBIDDEN_ENABLE', 'Povolit Plugin ACL pro uivatelsk skupiny?');
@define('PERMISSION_FORBIDDEN_ENABLE_DESC', 'Jestlie je volba "Plugin ACL pro uivatelsk skupiny" v konfiguraci povolena, mete urit, kter skupiny uivatel mohou provdt urit pluginy/udlosti.');
@define('IMPORT_WP_PAGES', 'Also fetch attachments and staticpages as normal blog entries?');
@define('USERCONF_CREATE', 'Disable user / forbid activity?');
@define('USERCONF_CREATE_DESC', 'If selected, the user will not have any editing or creation possibilities on the blog anymore. When logging in to the backend, he cannot do anything else apart from logging out and viewing his personal configuration.');
@define('CATEGORY_HIDE_SUB', 'Hide postings made to sub-categories?');
@define('CATEGORY_HIDE_SUB_DESC', 'By default, when you browse a category also entries of any subcategory are displayed. If this option is turned on, only postings of the currently selected category are displayed.');
@define('PINGBACK_SENDING', 'Sending pingback to URI %s...');
@define('PINGBACK_SENT', 'Pingback successful');
@define('PINGBACK_FAILED', 'Pingback failed: %s');
@define('PINGBACK_NOT_FOUND', 'No pingback-URI found.');
@define('CATEGORY_PLUGIN_HIDEZEROCOUNT', 'Hide archives link when no entries were made in that timespan (requires counting entries)');
@define('RSS_IMPORT_WPXRSS', 'WordPress eXtended RSS import, requires PHP5 and might take up much memory');
